@@ -3,7 +3,8 @@
 
 import networkx as nx
 
-from asymmetree.datastructures.Tree import TreeNode
+from tralda.datastructures import TreeNode
+
 from asymmetree.datastructures.PhyloTree import PhyloTreeNode
 
 
@@ -17,11 +18,11 @@ def augment_and_label(tree, inplace=False):
         tree = tree.copy()
     
     # precompute since tree will be modified
-    inner_vertices = [u for u in tree.inner_vertices()]
+    inner_nodes = [u for u in tree.inner_nodes()]
     tree.supply_leaves()
     current_ID = tree.get_max_ID() + 1
     
-    for u in inner_vertices:
+    for u in inner_nodes:
         
         # should not appear except if tree is planted, otherwise ignore
         if len(u.children) == 1:
@@ -69,7 +70,7 @@ def _color_intersection_components(u):
 
 if __name__ == '__main__':
     
-    from asymmetree.datastructures import PhyloTree
+    from asymmetree.datastructures.PhyloTree import PhyloTree
     from asymmetree.best_matches.LeastResolvedTree import lrt_from_observable_tree
     
     T = PhyloTree.random_colored_tree(30, 5)
