@@ -11,12 +11,14 @@ import itertools
 
 import networkx as nx
 
+from tralda.datastructures import Tree, TreeNode
+from tralda.tools.GraphTools import (sort_by_colors,
+                                     is_properly_colored,
+                                     graphs_equal)
+from tralda.supertree import Build
+
 from asymmetree.best_matches.TrueBMG import bmg_from_tree
 from asymmetree.datastructures.PhyloTree import PhyloTree, PhyloTreeNode
-from asymmetree.tools.GraphTools import (sort_by_colors,
-                                         is_properly_colored,
-                                         graphs_equal)
-from asymmetree.tools.Build import Build
 
 
 __author__ = 'David Schaller'
@@ -125,6 +127,10 @@ def _finalize(tree, G):
     
     if isinstance(tree, PhyloTreeNode):
         tree = PhyloTree(tree)
+    elif isinstance(tree, TreeNode):
+        tree = PhyloTree.to_phylotree(Tree(tree))
+    elif isinstance(tree, Tree):
+        tree = PhyloTree.to_phylotree(tree)
     
     # assign IDs to inner nodes
     tree.reconstruct_IDs()
@@ -259,6 +265,7 @@ def is_bmg(G):
             return False
         else:
             # a digraph is a BMG iff its equal to the BMG of BUILD(R)
+            subtree = PhyloTree.to_phylotree(subtree)
             subtree.reconstruct_info_from_graph(sg)
             if not graphs_equal(sg, bmg_from_tree(subtree)):
                 return False
@@ -445,7 +452,7 @@ if __name__ == '__main__':
     
     print('--- LRT1 ---\n', lrt1.to_newick())
     print('--- LRT2 ---\n', lrt2.to_newick())
-    print('LRTs equal: {}'.format( lrt1.compare_topology(lrt2) ))
+    print('LRTs equal: {}'.format( lrt1.equal_topology(lrt2) ))
     
     bmg = bmg_from_tree(T)
     
@@ -457,5 +464,5 @@ if __name__ == '__main__':
     lrt4 = lrt_from_observable_tree(T)
     print('--- LRT3 ---\n', lrt3.to_newick())
     print('--- LRT4 ---\n', lrt4.to_newick())
-    print('LRTs equal: {}'.format( lrt3.compare_topology(lrt4) ))
+    print('LRTs equal: {}'.format( lrt3.equal_topology(lrt4) ))
     print(end_time1 - start_time1, end_time2 - start_time2)
\ No newline at end of file
